@@ -5,10 +5,8 @@ import rna_prop_ui
 import bl_ui.utils
 import bl_ui.properties_grease_pencil_common
 
-GenericType = typing.TypeVar("GenericType")
 
-
-class GPENCIL_MT_color_context_menu(bpy_types.Menu, bpy_types._GenericUI):
+class GPENCIL_MT_material_context_menu(bpy_types.Menu, bpy_types._GenericUI):
     bl_label = None
     ''' '''
 
