@@ -3,8 +3,6 @@ import typing
 import bpy_types
 import bl_ui.properties_grease_pencil_common
 
-GenericType = typing.TypeVar("GenericType")
-
 
 class RENDER_PT_context(bpy_types.Panel, bpy_types._GenericUI):
     bl_context = None
@@ -1366,204 +1364,6 @@ class RENDER_PT_eevee_film(RenderButtonsPanel, bpy_types.Panel,
         pass
 
 
-class RENDER_PT_eevee_film_overscan(RenderButtonsPanel, bpy_types.Panel,
-                                    bpy_types._GenericUI):
-    COMPAT_ENGINES = None
-    ''' '''
-
-    bl_context = None
-    ''' '''
-
-    bl_label = None
-    ''' '''
-
-    bl_options = None
-    ''' '''
-
-    bl_parent_id = None
-    ''' '''
-
-    bl_region_type = None
-    ''' '''
-
-    bl_rna = None
-    ''' '''
-
-    bl_space_type = None
-    ''' '''
-
-    id_data = None
-    ''' '''
-
-    def append(self, draw_func):
-        ''' 
-
-        '''
-        pass
-
-    def as_pointer(self):
-        ''' 
-
-        '''
-        pass
-
-    def bl_rna_get_subclass(self):
-        ''' 
-
-        '''
-        pass
-
-    def bl_rna_get_subclass_py(self):
-        ''' 
-
-        '''
-        pass
-
-    def draw(self, context):
-        ''' 
-
-        '''
-        pass
-
-    def draw_header(self, context):
-        ''' 
-
-        '''
-        pass
-
-    def driver_add(self):
-        ''' 
-
-        '''
-        pass
-
-    def driver_remove(self):
-        ''' 
-
-        '''
-        pass
-
-    def get(self):
-        ''' 
-
-        '''
-        pass
-
-    def is_extended(self):
-        ''' 
-
-        '''
-        pass
-
-    def is_property_hidden(self):
-        ''' 
-
-        '''
-        pass
-
-    def is_property_overridable_library(self):
-        ''' 
-
-        '''
-        pass
-
-    def is_property_readonly(self):
-        ''' 
-
-        '''
-        pass
-
-    def is_property_set(self):
-        ''' 
-
-        '''
-        pass
-
-    def items(self):
-        ''' 
-
-        '''
-        pass
-
-    def keyframe_delete(self):
-        ''' 
-
-        '''
-        pass
-
-    def keyframe_insert(self):
-        ''' 
-
-        '''
-        pass
-
-    def keys(self):
-        ''' 
-
-        '''
-        pass
-
-    def path_from_id(self):
-        ''' 
-
-        '''
-        pass
-
-    def path_resolve(self):
-        ''' 
-
-        '''
-        pass
-
-    def poll(self, context):
-        ''' 
-
-        '''
-        pass
-
-    def pop(self):
-        ''' 
-
-        '''
-        pass
-
-    def prepend(self, draw_func):
-        ''' 
-
-        '''
-        pass
-
-    def property_overridable_library_set(self):
-        ''' 
-
-        '''
-        pass
-
-    def property_unset(self):
-        ''' 
-
-        '''
-        pass
-
-    def remove(self, draw_func):
-        ''' 
-
-        '''
-        pass
-
-    def type_recast(self):
-        ''' 
-
-        '''
-        pass
-
-    def values(self):
-        ''' 
-
-        '''
-        pass
-
-
 class RENDER_PT_eevee_hair(RenderButtonsPanel, bpy_types.Panel,
                            bpy_types._GenericUI):
     COMPAT_ENGINES = None
@@ -3864,6 +3664,9 @@ class RENDER_PT_gpencil(RenderButtonsPanel, bpy_types.Panel,
     bl_options = None
     ''' '''
 
+    bl_order = None
+    ''' '''
+
     bl_region_type = None
     ''' '''
 
