@@ -2,8 +2,6 @@ import sys
 import typing
 import bpy_types
 
-GenericType = typing.TypeVar("GenericType")
-
 
 class OUTLINER_HT_header(bpy_types.Header, bpy_types._GenericUI):
     bl_rna = None
@@ -968,6 +966,12 @@ class OUTLINER_MT_context_menu(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
+    def draw_common_operators(self, layout):
+        ''' 
+
+        '''
+        pass
+
     def draw_preset(self, _context):
         ''' 
 
