@@ -41,8 +41,8 @@ def beautify_fill(
 
 
 def bevel(bm: 'bmesh.types.BMesh', geom: typing.
-          Union[typing.List['bmesh.types.BMEdge'], typing.
-                List['bmesh.types.BMFace'], typing.List['bmesh.types.BMVert']],
+          Union[typing.List['bmesh.types.BMFace'], typing.
+                List['bmesh.types.BMEdge'], typing.List['bmesh.types.BMVert']],
           offset: float, offset_type: typing.Union[int, str],
           profile_type: typing.Union[int, str], segments: int, profile: float,
           affect: typing.Union[int, str], clamp_overlap: bool, material: int,
@@ -57,7 +57,7 @@ def bevel(bm: 'bmesh.types.BMesh', geom: typing.
     :param bm: The bmesh to operate on.
     :type bm: 'bmesh.types.BMesh'
     :param geom: input edges and vertices
-    :type geom: typing.Union[typing.List['bmesh.types.BMEdge'], typing.List['bmesh.types.BMFace'], typing.List['bmesh.types.BMVert']]
+    :type geom: typing.Union[typing.List['bmesh.types.BMFace'], typing.List['bmesh.types.BMEdge'], typing.List['bmesh.types.BMVert']]
     :param offset: amount to offset beveled edge
     :type offset: float
     :param offset_type: how to measure the offset
@@ -123,8 +123,8 @@ def bisect_edges(bm: 'bmesh.types.BMesh',
 
 def bisect_plane(
         bm: 'bmesh.types.BMesh', geom: typing.
-        Union[typing.List['bmesh.types.BMEdge'], typing.
-              List['bmesh.types.BMFace'], typing.List['bmesh.types.BMVert']],
+        Union[typing.List['bmesh.types.BMFace'], typing.
+              List['bmesh.types.BMEdge'], typing.List['bmesh.types.BMVert']],
         dist: float, plane_co: typing.List['mathutils.Vector'],
         plane_no: typing.List['mathutils.Vector'], use_snap_center: bool,
         clear_outer: bool, clear_inner: bool) -> dict:
@@ -133,7 +133,7 @@ def bisect_plane(
     :param bm: The bmesh to operate on.
     :type bm: 'bmesh.types.BMesh'
     :param geom: Undocumented.
-    :type geom: typing.Union[typing.List['bmesh.types.BMEdge'], typing.List['bmesh.types.BMFace'], typing.List['bmesh.types.BMVert']]
+    :type geom: typing.Union[typing.List['bmesh.types.BMFace'], typing.List['bmesh.types.BMEdge'], typing.List['bmesh.types.BMVert']]
     :param dist: minimum distance when testing if a vert is exactly on the plane
     :type dist: float
     :param plane_co: point on the plane
@@ -293,15 +293,15 @@ def connect_verts_nonplanar(bm: 'bmesh.types.BMesh', angle_limit: float,
 
 def contextual_create(
         bm: 'bmesh.types.BMesh', geom: typing.
-        Union[typing.List['bmesh.types.BMEdge'], typing.
-              List['bmesh.types.BMFace'], typing.List['bmesh.types.BMVert']],
+        Union[typing.List['bmesh.types.BMFace'], typing.
+              List['bmesh.types.BMEdge'], typing.List['bmesh.types.BMVert']],
         mat_nr: int, use_smooth: bool) -> dict:
     ''' Contextual Create. This is basically F-key, it creates new faces from vertices, makes stuff from edge nets, makes wire edges, etc. It also dissolves faces. Three verts become a triangle, four become a quad. Two become a wire edge.
 
     :param bm: The bmesh to operate on.
     :type bm: 'bmesh.types.BMesh'
     :param geom: input geometry.
-    :type geom: typing.Union[typing.List['bmesh.types.BMEdge'], typing.List['bmesh.types.BMFace'], typing.List['bmesh.types.BMVert']]
+    :type geom: typing.Union[typing.List['bmesh.types.BMFace'], typing.List['bmesh.types.BMEdge'], typing.List['bmesh.types.BMVert']]
     :param mat_nr: material to use
     :type mat_nr: int
     :param use_smooth: smooth to use
@@ -313,8 +313,8 @@ def contextual_create(
 
 
 def convex_hull(bm: 'bmesh.types.BMesh',
-                input: typing.Union[typing.List['bmesh.types.BMEdge'], typing.
-                                    List['bmesh.types.BMFace'], typing.
+                input: typing.Union[typing.List['bmesh.types.BMFace'], typing.
+                                    List['bmesh.types.BMEdge'], typing.
                                     List['bmesh.types.BMVert']],
                 use_existing_faces: bool) -> dict:
     ''' Convex Hull Builds a convex hull from the vertices in 'input'. If 'use_existing_faces' is true, the hull will not output triangles that are covered by a pre-existing face. All hull vertices, faces, and edges are added to 'geom.out'. Any input elements that end up inside the hull (i.e. are not used by an output face) are added to the 'interior_geom' slot. The 'unused_geom' slot will contain all interior geometry that is completely unused. Lastly, 'holes_geom' contains edges and faces that were in the input and are part of the hull.
@@ -322,7 +322,7 @@ def convex_hull(bm: 'bmesh.types.BMesh',
     :param bm: The bmesh to operate on.
     :type bm: 'bmesh.types.BMesh'
     :param input: Undocumented.
-    :type input: typing.Union[typing.List['bmesh.types.BMEdge'], typing.List['bmesh.types.BMFace'], typing.List['bmesh.types.BMVert']]
+    :type input: typing.Union[typing.List['bmesh.types.BMFace'], typing.List['bmesh.types.BMEdge'], typing.List['bmesh.types.BMVert']]
     :param use_existing_faces: Undocumented.
     :type use_existing_faces: bool
     :return: - geom : **type** list of ( bmesh.types.BMVert , bmesh.types.BMEdge , bmesh.types.BMFace ) - geom_interior : **type** list of ( bmesh.types.BMVert , bmesh.types.BMEdge , bmesh.types.BMFace ) - geom_unused : **type** list of ( bmesh.types.BMVert , bmesh.types.BMEdge , bmesh.types.BMFace ) - geom_holes : **type** list of ( bmesh.types.BMVert , bmesh.types.BMEdge , bmesh.types.BMFace )
@@ -502,8 +502,8 @@ def create_vert(bm: 'bmesh.types.BMesh',
 
 
 def delete(bm: 'bmesh.types.BMesh',
-           geom: typing.Union[typing.List['bmesh.types.BMEdge'], typing.
-                              List['bmesh.types.BMFace'], typing.
+           geom: typing.Union[typing.List['bmesh.types.BMFace'], typing.
+                              List['bmesh.types.BMEdge'], typing.
                               List['bmesh.types.BMVert']],
            context: typing.Union[int, str]):
     ''' Delete Geometry. Utility operator to delete geometry.
@@ -511,7 +511,7 @@ def delete(bm: 'bmesh.types.BMesh',
     :param bm: The bmesh to operate on.
     :type bm: 'bmesh.types.BMesh'
     :param geom: Undocumented.
-    :type geom: typing.Union[typing.List['bmesh.types.BMEdge'], typing.List['bmesh.types.BMFace'], typing.List['bmesh.types.BMVert']]
+    :type geom: typing.Union[typing.List['bmesh.types.BMFace'], typing.List['bmesh.types.BMEdge'], typing.List['bmesh.types.BMVert']]
     :param context: geometry types to delete
     :type context: typing.Union[int, str]
     '''
@@ -614,8 +614,8 @@ def dissolve_verts(bm: 'bmesh.types.BMesh',
 
 
 def duplicate(bm: 'bmesh.types.BMesh',
-              geom: typing.Union[typing.List['bmesh.types.BMEdge'], typing.
-                                 List['bmesh.types.BMFace'], typing.
+              geom: typing.Union[typing.List['bmesh.types.BMFace'], typing.
+                                 List['bmesh.types.BMEdge'], typing.
                                  List['bmesh.types.BMVert']],
               dest: 'bmesh.types.BMesh', use_select_history: bool,
               use_edge_flip_from_face: bool) -> dict:
@@ -624,7 +624,7 @@ def duplicate(bm: 'bmesh.types.BMesh',
     :param bm: The bmesh to operate on.
     :type bm: 'bmesh.types.BMesh'
     :param geom: Undocumented.
-    :type geom: typing.Union[typing.List['bmesh.types.BMEdge'], typing.List['bmesh.types.BMFace'], typing.List['bmesh.types.BMVert']]
+    :type geom: typing.Union[typing.List['bmesh.types.BMFace'], typing.List['bmesh.types.BMEdge'], typing.List['bmesh.types.BMVert']]
     :param dest: Undocumented.
     :type dest: 'bmesh.types.BMesh'
     :param use_select_history: Undocumented.
@@ -731,8 +731,8 @@ def extrude_edge_only(bm: 'bmesh.types.BMesh',
 
 def extrude_face_region(
         bm: 'bmesh.types.BMesh',
-        geom: typing.Union[typing.List['bmesh.types.BMEdge'], typing.
-                           List['bmesh.types.BMFace'], typing.
+        geom: typing.Union[typing.List['bmesh.types.BMFace'], typing.
+                           List['bmesh.types.BMEdge'], typing.
                            List['bmesh.types.BMVert']] = [],
         edges_exclude: set = [],
         use_keep_orig: bool = False,
@@ -745,7 +745,7 @@ def extrude_face_region(
     :param bm: The bmesh to operate on.
     :type bm: 'bmesh.types.BMesh'
     :param geom: edges and faces
-    :type geom: typing.Union[typing.List['bmesh.types.BMEdge'], typing.List['bmesh.types.BMFace'], typing.List['bmesh.types.BMVert']]
+    :type geom: typing.Union[typing.List['bmesh.types.BMFace'], typing.List['bmesh.types.BMEdge'], typing.List['bmesh.types.BMVert']]
     :param edges_exclude: Undocumented.
     :type edges_exclude: set
     :param use_keep_orig: keep original geometry (requires geom to include edges).
@@ -967,8 +967,8 @@ def mesh_to_bmesh(bm: 'bmesh.types.BMesh', mesh: 'bpy.types.Mesh',
 
 
 def mirror(bm: 'bmesh.types.BMesh',
-           geom: typing.Union[typing.List['bmesh.types.BMEdge'], typing.
-                              List['bmesh.types.BMFace'], typing.
+           geom: typing.Union[typing.List['bmesh.types.BMFace'], typing.
+                              List['bmesh.types.BMEdge'], typing.
                               List['bmesh.types.BMVert']],
            matrix: 'mathutils.Matrix', merge_dist: float,
            axis: typing.Union[int, str], mirror_u: bool, mirror_v: bool,
@@ -978,7 +978,7 @@ def mirror(bm: 'bmesh.types.BMesh',
     :param bm: The bmesh to operate on.
     :type bm: 'bmesh.types.BMesh'
     :param geom: input geometry
-    :type geom: typing.Union[typing.List['bmesh.types.BMEdge'], typing.List['bmesh.types.BMFace'], typing.List['bmesh.types.BMVert']]
+    :type geom: typing.Union[typing.List['bmesh.types.BMFace'], typing.List['bmesh.types.BMEdge'], typing.List['bmesh.types.BMVert']]
     :param matrix: matrix defining the mirror transformation
     :type matrix: 'mathutils.Matrix'
     :param merge_dist: maximum distance for merging. does no merging if 0.
@@ -1116,15 +1116,15 @@ def recalc_face_normals(bm: 'bmesh.types.BMesh',
 
 def region_extend(
         bm: 'bmesh.types.BMesh', geom: typing.
-        Union[typing.List['bmesh.types.BMEdge'], typing.
-              List['bmesh.types.BMFace'], typing.List['bmesh.types.BMVert']],
+        Union[typing.List['bmesh.types.BMFace'], typing.
+              List['bmesh.types.BMEdge'], typing.List['bmesh.types.BMVert']],
         use_contract: bool, use_faces: bool, use_face_step: bool) -> dict:
     ''' Region Extend. used to implement the select more/less tools. this puts some geometry surrounding regions of geometry in geom into geom.out. if use_faces is 0 then geom.out spits out verts and edges, otherwise it spits out faces.
 
     :param bm: The bmesh to operate on.
     :type bm: 'bmesh.types.BMesh'
     :param geom: input geometry
-    :type geom: typing.Union[typing.List['bmesh.types.BMEdge'], typing.List['bmesh.types.BMFace'], typing.List['bmesh.types.BMVert']]
+    :type geom: typing.Union[typing.List['bmesh.types.BMFace'], typing.List['bmesh.types.BMEdge'], typing.List['bmesh.types.BMVert']]
     :param use_contract: find boundary inside the regions, not outside.
     :type use_contract: bool
     :param use_faces: extend from faces instead of edges
@@ -1339,8 +1339,8 @@ def smooth_vert(bm: 'bmesh.types.BMesh',
 
 
 def solidify(bm: 'bmesh.types.BMesh',
-             geom: typing.Union[typing.List['bmesh.types.BMEdge'], typing.
-                                List['bmesh.types.BMFace'], typing.
+             geom: typing.Union[typing.List['bmesh.types.BMFace'], typing.
+                                List['bmesh.types.BMEdge'], typing.
                                 List['bmesh.types.BMVert']],
              thickness: float) -> dict:
     ''' Solidify. Turns a mesh into a shell with thickness
@@ -1348,7 +1348,7 @@ def solidify(bm: 'bmesh.types.BMesh',
     :param bm: The bmesh to operate on.
     :type bm: 'bmesh.types.BMesh'
     :param geom: Undocumented.
-    :type geom: typing.Union[typing.List['bmesh.types.BMEdge'], typing.List['bmesh.types.BMFace'], typing.List['bmesh.types.BMVert']]
+    :type geom: typing.Union[typing.List['bmesh.types.BMFace'], typing.List['bmesh.types.BMEdge'], typing.List['bmesh.types.BMVert']]
     :param thickness: Undocumented.
     :type thickness: float
     :return: - geom : **type** list of ( bmesh.types.BMVert , bmesh.types.BMEdge , bmesh.types.BMFace )
@@ -1358,8 +1358,8 @@ def solidify(bm: 'bmesh.types.BMesh',
 
 
 def spin(bm: 'bmesh.types.BMesh', geom: typing.
-         Union[typing.List['bmesh.types.BMEdge'], typing.
-               List['bmesh.types.BMFace'], typing.List['bmesh.types.BMVert']],
+         Union[typing.List['bmesh.types.BMFace'], typing.
+               List['bmesh.types.BMEdge'], typing.List['bmesh.types.BMVert']],
          cent: typing.List['mathutils.Vector'],
          axis: typing.List['mathutils.Vector'],
          dvec: typing.List['mathutils.Vector'], angle: float,
@@ -1370,7 +1370,7 @@ def spin(bm: 'bmesh.types.BMesh', geom: typing.
     :param bm: The bmesh to operate on.
     :type bm: 'bmesh.types.BMesh'
     :param geom: Undocumented.
-    :type geom: typing.Union[typing.List['bmesh.types.BMEdge'], typing.List['bmesh.types.BMFace'], typing.List['bmesh.types.BMVert']]
+    :type geom: typing.Union[typing.List['bmesh.types.BMFace'], typing.List['bmesh.types.BMEdge'], typing.List['bmesh.types.BMVert']]
     :param cent: rotation center
     :type cent: typing.List['mathutils.Vector']
     :param axis: rotation axis
@@ -1396,15 +1396,15 @@ def spin(bm: 'bmesh.types.BMesh', geom: typing.
 
 
 def split(bm: 'bmesh.types.BMesh', geom: typing.
-          Union[typing.List['bmesh.types.BMEdge'], typing.
-                List['bmesh.types.BMFace'], typing.List['bmesh.types.BMVert']],
+          Union[typing.List['bmesh.types.BMFace'], typing.
+                List['bmesh.types.BMEdge'], typing.List['bmesh.types.BMVert']],
           dest: 'bmesh.types.BMesh', use_only_faces: bool) -> dict:
     ''' Split Off Geometry. Disconnect geometry from adjacent edges and faces, optionally into a destination mesh.
 
     :param bm: The bmesh to operate on.
     :type bm: 'bmesh.types.BMesh'
     :param geom: Undocumented.
-    :type geom: typing.Union[typing.List['bmesh.types.BMEdge'], typing.List['bmesh.types.BMFace'], typing.List['bmesh.types.BMVert']]
+    :type geom: typing.Union[typing.List['bmesh.types.BMFace'], typing.List['bmesh.types.BMEdge'], typing.List['bmesh.types.BMVert']]
     :param dest: Undocumented.
     :type dest: 'bmesh.types.BMesh'
     :param use_only_faces: when enabled. don't duplicate loose verts/edges
@@ -1509,8 +1509,8 @@ def subdivide_edges(
 
 
 def symmetrize(bm: 'bmesh.types.BMesh',
-               input: typing.Union[typing.List['bmesh.types.BMEdge'], typing.
-                                   List['bmesh.types.BMFace'], typing.
+               input: typing.Union[typing.List['bmesh.types.BMFace'], typing.
+                                   List['bmesh.types.BMEdge'], typing.
                                    List['bmesh.types.BMVert']],
                direction: typing.Union[int, str], dist: float) -> dict:
     ''' Symmetrize. Makes the mesh elements in the "input" slot symmetrical. Unlike normal mirroring, it only copies in one direction, as specified by the "direction" slot. The edges and faces that cross the plane of symmetry are split as needed to enforce symmetry. All new vertices, edges, and faces are added to the "geom.out" slot.
@@ -1518,7 +1518,7 @@ def symmetrize(bm: 'bmesh.types.BMesh',
     :param bm: The bmesh to operate on.
     :type bm: 'bmesh.types.BMesh'
     :param input: Undocumented.
-    :type input: typing.Union[typing.List['bmesh.types.BMEdge'], typing.List['bmesh.types.BMFace'], typing.List['bmesh.types.BMVert']]
+    :type input: typing.Union[typing.List['bmesh.types.BMFace'], typing.List['bmesh.types.BMEdge'], typing.List['bmesh.types.BMVert']]
     :param direction: axis to use
     :type direction: typing.Union[int, str]
     :param dist: minimum distance
