@@ -1,30 +1,16 @@
 import sys
 import typing
-import bpy.types
-
-GenericType = typing.TypeVar("GenericType")
 
 
-def context_menu(override_context: typing.
-                 Union[typing.Dict, 'bpy.types.Context'] = None,
-                 execution_context: typing.Union[str, int] = None,
-                 undo: bool = None):
+def context_menu():
     ''' Display properties editor context_menu
 
-    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
-    :type execution_context: typing.Union[str, int]
-    :type undo: bool
     '''
 
     pass
 
 
-def directory_browse(override_context: typing.
-                     Union[typing.Dict, 'bpy.types.Context'] = None,
-                     execution_context: typing.Union[str, int] = None,
-                     undo: bool = None,
-                     *,
-                     directory: str = "",
+def directory_browse(directory: str = "",
                      hide_props_region: bool = True,
                      filter_blender: bool = False,
                      filter_backup: bool = False,
@@ -44,13 +30,10 @@ def directory_browse(override_context: typing.
                      filter_blenlib: bool = False,
                      filemode: int = 9,
                      relative_path: bool = True,
-                     display_type: typing.Union[str, int] = 'DEFAULT',
-                     sort_method: typing.Union[str, int] = 'FILE_SORT_ALPHA'):
+                     display_type: typing.Union[int, str] = 'DEFAULT',
+                     sort_method: typing.Union[int, str] = 'FILE_SORT_ALPHA'):
     ''' Open a directory browser, Hold Shift to open the file, Alt to browse containing directory
 
-    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
-    :type execution_context: typing.Union[str, int]
-    :type undo: bool
     :param directory: Directory, Directory of the file
     :type directory: str
     :param hide_props_region: Hide Operator Properties, Collapse the region displaying the operator settings
@@ -92,20 +75,15 @@ def directory_browse(override_context: typing.
     :param relative_path: Relative Path, Select the file relative to the blend file
     :type relative_path: bool
     :param display_type: Display Type * DEFAULT Default, Automatically determine display type for files. * LIST_VERTICAL Short List, Display files as short list. * LIST_HORIZONTAL Long List, Display files as a detailed list. * THUMBNAIL Thumbnails, Display files as thumbnails.
-    :type display_type: typing.Union[str, int]
+    :type display_type: typing.Union[int, str]
     :param sort_method: File sorting mode * FILE_SORT_ALPHA Name, Sort the file list alphabetically. * FILE_SORT_EXTENSION Extension, Sort the file list by extension/type. * FILE_SORT_TIME Modified Date, Sort files by modification time. * FILE_SORT_SIZE Size, Sort files by size.
-    :type sort_method: typing.Union[str, int]
+    :type sort_method: typing.Union[int, str]
     '''
 
     pass
 
 
-def file_browse(override_context: typing.
-                Union[typing.Dict, 'bpy.types.Context'] = None,
-                execution_context: typing.Union[str, int] = None,
-                undo: bool = None,
-                *,
-                filepath: str = "",
+def file_browse(filepath: str = "",
                 hide_props_region: bool = True,
                 filter_blender: bool = False,
                 filter_backup: bool = False,
@@ -125,13 +103,10 @@ def file_browse(override_context: typing.
                 filter_blenlib: bool = False,
                 filemode: int = 9,
                 relative_path: bool = True,
-                display_type: typing.Union[str, int] = 'DEFAULT',
-                sort_method: typing.Union[str, int] = 'FILE_SORT_ALPHA'):
+                display_type: typing.Union[int, str] = 'DEFAULT',
+                sort_method: typing.Union[int, str] = 'FILE_SORT_ALPHA'):
     ''' Open a file browser, Hold Shift to open the file, Alt to browse containing directory
 
-    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
-    :type execution_context: typing.Union[str, int]
-    :type undo: bool
     :param filepath: File Path, Path to file
     :type filepath: str
     :param hide_props_region: Hide Operator Properties, Collapse the region displaying the operator settings
@@ -173,9 +148,9 @@ def file_browse(override_context: typing.
     :param relative_path: Relative Path, Select the file relative to the blend file
     :type relative_path: bool
     :param display_type: Display Type * DEFAULT Default, Automatically determine display type for files. * LIST_VERTICAL Short List, Display files as short list. * LIST_HORIZONTAL Long List, Display files as a detailed list. * THUMBNAIL Thumbnails, Display files as thumbnails.
-    :type display_type: typing.Union[str, int]
+    :type display_type: typing.Union[int, str]
     :param sort_method: File sorting mode * FILE_SORT_ALPHA Name, Sort the file list alphabetically. * FILE_SORT_EXTENSION Extension, Sort the file list by extension/type. * FILE_SORT_TIME Modified Date, Sort files by modification time. * FILE_SORT_SIZE Size, Sort files by size.
-    :type sort_method: typing.Union[str, int]
+    :type sort_method: typing.Union[int, str]
     '''
 
     pass
