@@ -61,8 +61,10 @@ def draw(error_threshold: float = 0.0,
          fit_method: typing.Union[int, str] = 'REFIT',
          corner_angle: float = 1.22173,
          use_cyclic: bool = True,
-         stroke: typing.Union[typing.List['bpy.types.OperatorStrokeElement'],
-                              'bpy_prop_collection'] = None,
+         stroke: typing.
+         Union[typing.Dict[str, 'bpy.types.OperatorStrokeElement'], typing.
+               List['bpy.types.OperatorStrokeElement'],
+               'bpy_prop_collection'] = None,
          wait_for_input: bool = True):
     ''' Draw a freehand spline
 
@@ -75,7 +77,7 @@ def draw(error_threshold: float = 0.0,
     :param use_cyclic: Cyclic
     :type use_cyclic: bool
     :param stroke: Stroke
-    :type stroke: typing.Union[typing.List['bpy.types.OperatorStrokeElement'], 'bpy_prop_collection']
+    :type stroke: typing.Union[typing.Dict[str, 'bpy.types.OperatorStrokeElement'], typing.List['bpy.types.OperatorStrokeElement'], 'bpy_prop_collection']
     :param wait_for_input: Wait for Input
     :type wait_for_input: bool
     '''
