@@ -19,16 +19,17 @@ def active_frames_delete_all():
     pass
 
 
-def annotate(
-        mode: typing.Union[int, str] = 'DRAW',
-        arrowstyle_start: typing.Union[int, str] = 'NONE',
-        arrowstyle_end: typing.Union[int, str] = 'NONE',
-        use_stabilizer: bool = False,
-        stabilizer_factor: float = 0.75,
-        stabilizer_radius: int = 35,
-        stroke: typing.Union[typing.List['bpy.types.OperatorStrokeElement'],
-                             'bpy_prop_collection'] = None,
-        wait_for_input: bool = True):
+def annotate(mode: typing.Union[int, str] = 'DRAW',
+             arrowstyle_start: typing.Union[int, str] = 'NONE',
+             arrowstyle_end: typing.Union[int, str] = 'NONE',
+             use_stabilizer: bool = False,
+             stabilizer_factor: float = 0.75,
+             stabilizer_radius: int = 35,
+             stroke: typing.
+             Union[typing.Dict[str, 'bpy.types.OperatorStrokeElement'], typing.
+                   List['bpy.types.OperatorStrokeElement'],
+                   'bpy_prop_collection'] = None,
+             wait_for_input: bool = True):
     ''' Make annotations on the active data
 
     :param mode: Mode, Way to interpret mouse movements * DRAW Draw Freehand, Draw freehand stroke(s). * DRAW_STRAIGHT Draw Straight Lines, Draw straight line segment(s). * DRAW_POLY Draw Poly Line, Click to place endpoints of straight line segments (connected). * ERASER Eraser, Erase Annotation strokes.
@@ -44,7 +45,7 @@ def annotate(
     :param stabilizer_radius: Stabilizer Stroke Radius, Minimum distance from last point before stroke continues
     :type stabilizer_radius: int
     :param stroke: Stroke
-    :type stroke: typing.Union[typing.List['bpy.types.OperatorStrokeElement'], 'bpy_prop_collection']
+    :type stroke: typing.Union[typing.Dict[str, 'bpy.types.OperatorStrokeElement'], typing.List['bpy.types.OperatorStrokeElement'], 'bpy_prop_collection']
     :param wait_for_input: Wait for Input, Wait for first click instead of painting immediately
     :type wait_for_input: bool
     '''
@@ -233,8 +234,10 @@ def dissolve(type: typing.Union[int, str] = 'POINTS'):
 
 
 def draw(mode: typing.Union[int, str] = 'DRAW',
-         stroke: typing.Union[typing.List['bpy.types.OperatorStrokeElement'],
-                              'bpy_prop_collection'] = None,
+         stroke: typing.
+         Union[typing.Dict[str, 'bpy.types.OperatorStrokeElement'], typing.
+               List['bpy.types.OperatorStrokeElement'],
+               'bpy_prop_collection'] = None,
          wait_for_input: bool = True,
          disable_straight: bool = False,
          disable_fill: bool = False,
@@ -244,7 +247,7 @@ def draw(mode: typing.Union[int, str] = 'DRAW',
     :param mode: Mode, Way to interpret mouse movements * DRAW Draw Freehand, Draw freehand stroke(s). * DRAW_STRAIGHT Draw Straight Lines, Draw straight line segment(s). * ERASER Eraser, Erase Grease Pencil strokes.
     :type mode: typing.Union[int, str]
     :param stroke: Stroke
-    :type stroke: typing.Union[typing.List['bpy.types.OperatorStrokeElement'], 'bpy_prop_collection']
+    :type stroke: typing.Union[typing.Dict[str, 'bpy.types.OperatorStrokeElement'], typing.List['bpy.types.OperatorStrokeElement'], 'bpy_prop_collection']
     :param wait_for_input: Wait for Input, Wait for first click instead of painting immediately
     :type wait_for_input: bool
     :param disable_straight: No Straight lines, Disable key for straight lines
@@ -800,14 +803,14 @@ def reveal(select: bool = True):
     pass
 
 
-def sculpt_paint(
-        stroke: typing.Union[typing.List['bpy.types.OperatorStrokeElement'],
-                             'bpy_prop_collection'] = None,
-        wait_for_input: bool = True):
+def sculpt_paint(stroke: typing.Union[
+        typing.Dict[str, 'bpy.types.OperatorStrokeElement'], typing.
+        List['bpy.types.OperatorStrokeElement'], 'bpy_prop_collection'] = None,
+                 wait_for_input: bool = True):
     ''' Apply tweaks to strokes by painting over the strokes
 
     :param stroke: Stroke
-    :type stroke: typing.Union[typing.List['bpy.types.OperatorStrokeElement'], 'bpy_prop_collection']
+    :type stroke: typing.Union[typing.Dict[str, 'bpy.types.OperatorStrokeElement'], typing.List['bpy.types.OperatorStrokeElement'], 'bpy_prop_collection']
     :param wait_for_input: Wait for Input, Enter a mini 'sculpt-mode' if enabled, otherwise, exit after drawing a single stroke
     :type wait_for_input: bool
     '''
@@ -943,14 +946,16 @@ def select_grouped(type: typing.Union[int, str] = 'LAYER'):
 
 
 def select_lasso(mode: typing.Union[int, str] = 'SET',
-                 path: typing.Union[typing.List['bpy.types.OperatorMousePath'],
-                                    'bpy_prop_collection'] = None):
+                 path: typing.
+                 Union[typing.Dict[str, 'bpy.types.OperatorMousePath'], typing.
+                       List['bpy.types.OperatorMousePath'],
+                       'bpy_prop_collection'] = None):
     ''' Select Grease Pencil strokes using lasso selection
 
     :param mode: Mode * SET Set, Set a new selection. * ADD Extend, Extend existing selection. * SUB Subtract, Subtract existing selection. * XOR Difference, Inverts existing selection. * AND Intersect, Intersect existing selection.
     :type mode: typing.Union[int, str]
     :param path: Path
-    :type path: typing.Union[typing.List['bpy.types.OperatorMousePath'], 'bpy_prop_collection']
+    :type path: typing.Union[typing.Dict[str, 'bpy.types.OperatorMousePath'], typing.List['bpy.types.OperatorMousePath'], 'bpy_prop_collection']
     '''
 
     pass
@@ -1092,13 +1097,13 @@ def stroke_change_color(material: str = ""):
     pass
 
 
-def stroke_cutter(
-        path: typing.Union[typing.List['bpy.types.OperatorMousePath'],
-                           'bpy_prop_collection'] = None):
+def stroke_cutter(path: typing.Union[
+        typing.Dict[str, 'bpy.types.OperatorMousePath'], typing.
+        List['bpy.types.OperatorMousePath'], 'bpy_prop_collection'] = None):
     ''' Select section and cut
 
     :param path: Path
-    :type path: typing.Union[typing.List['bpy.types.OperatorMousePath'], 'bpy_prop_collection']
+    :type path: typing.Union[typing.Dict[str, 'bpy.types.OperatorMousePath'], typing.List['bpy.types.OperatorMousePath'], 'bpy_prop_collection']
     '''
 
     pass
@@ -1308,7 +1313,7 @@ def stroke_trim():
 
 
 def tint_flip():
-    ''' Switch Tint colors
+    ''' Switch Tint colors :file: startup/bl_ui/properties_grease_pencil_common.py\:894 <https://developer.blender.org/diffusion/B/browse/master/release/scripts/startup/bl_ui/properties_grease_pencil_common.py$894> _
 
     '''
 
@@ -1489,14 +1494,14 @@ def vertex_group_smooth(factor: float = 0.5, repeat: int = 1):
     pass
 
 
-def vertex_paint(
-        stroke: typing.Union[typing.List['bpy.types.OperatorStrokeElement'],
-                             'bpy_prop_collection'] = None,
-        wait_for_input: bool = True):
+def vertex_paint(stroke: typing.Union[
+        typing.Dict[str, 'bpy.types.OperatorStrokeElement'], typing.
+        List['bpy.types.OperatorStrokeElement'], 'bpy_prop_collection'] = None,
+                 wait_for_input: bool = True):
     ''' Paint stroke points with a color
 
     :param stroke: Stroke
-    :type stroke: typing.Union[typing.List['bpy.types.OperatorStrokeElement'], 'bpy_prop_collection']
+    :type stroke: typing.Union[typing.Dict[str, 'bpy.types.OperatorStrokeElement'], typing.List['bpy.types.OperatorStrokeElement'], 'bpy_prop_collection']
     :param wait_for_input: Wait for Input
     :type wait_for_input: bool
     '''
@@ -1514,14 +1519,14 @@ def vertexmode_toggle(back: bool = False):
     pass
 
 
-def weight_paint(
-        stroke: typing.Union[typing.List['bpy.types.OperatorStrokeElement'],
-                             'bpy_prop_collection'] = None,
-        wait_for_input: bool = True):
+def weight_paint(stroke: typing.Union[
+        typing.Dict[str, 'bpy.types.OperatorStrokeElement'], typing.
+        List['bpy.types.OperatorStrokeElement'], 'bpy_prop_collection'] = None,
+                 wait_for_input: bool = True):
     ''' Paint stroke points with a color
 
     :param stroke: Stroke
-    :type stroke: typing.Union[typing.List['bpy.types.OperatorStrokeElement'], 'bpy_prop_collection']
+    :type stroke: typing.Union[typing.Dict[str, 'bpy.types.OperatorStrokeElement'], typing.List['bpy.types.OperatorStrokeElement'], 'bpy_prop_collection']
     :param wait_for_input: Wait for Input
     :type wait_for_input: bool
     '''
