@@ -133,8 +133,10 @@ def new(name: str = "Untitled",
 
 def open(filepath: str = "",
          directory: str = "",
-         files: typing.Union[typing.List['bpy.types.OperatorFileListElement'],
-                             'bpy_prop_collection'] = None,
+         files: typing.
+         Union[typing.Dict[str, 'bpy.types.OperatorFileListElement'], typing.
+               List['bpy.types.OperatorFileListElement'],
+               'bpy_prop_collection'] = None,
          hide_props_region: bool = True,
          filter_blender: bool = False,
          filter_backup: bool = False,
@@ -167,7 +169,7 @@ def open(filepath: str = "",
     :param directory: Directory, Directory of the file
     :type directory: str
     :param files: Files
-    :type files: typing.Union[typing.List['bpy.types.OperatorFileListElement'], 'bpy_prop_collection']
+    :type files: typing.Union[typing.Dict[str, 'bpy.types.OperatorFileListElement'], typing.List['bpy.types.OperatorFileListElement'], 'bpy_prop_collection']
     :param hide_props_region: Hide Operator Properties, Collapse the region displaying the operator settings
     :type hide_props_region: bool
     :param filter_blender: Filter .blend files
@@ -232,7 +234,7 @@ def pack():
 
 
 def project_apply():
-    ''' Project edited image back onto the object
+    ''' Project edited image back onto the object :file: startup/bl_operators/image.py\:197 <https://developer.blender.org/diffusion/B/browse/master/release/scripts/startup/bl_operators/image.py$197> _
 
     '''
 
@@ -240,7 +242,7 @@ def project_apply():
 
 
 def project_edit():
-    ''' Edit a snapshot of the view-port in an external image editor
+    ''' Edit a snapshot of the view-port in an external image editor :file: startup/bl_operators/image.py\:126 <https://developer.blender.org/diffusion/B/browse/master/release/scripts/startup/bl_operators/image.py$126> _
 
     '''
 
