@@ -57,7 +57,7 @@ def opengl(animation: bool = False,
 
 
 def play_rendered_anim():
-    ''' Play back rendered frames/movies using an external player
+    ''' Play back rendered frames/movies using an external player :file: startup/bl_operators/screen_play_rendered_anim.py\:64 <https://developer.blender.org/diffusion/B/browse/master/release/scripts/startup/bl_operators/screen_play_rendered_anim.py$64> _
 
     '''
 
